@ECHO OFF
IF "%useverbose%"=="1" ECHO ON
REM ===================================================
REM This is the TST validation script
REM For help run TSTCheck.bat /?
REM ===================================================
SETLOCAL

REM Setting up variables
SET TC_ExitCode=0
SET TC_SqlOutput="%Temp%\TC_SqlOutput.txt"
SET TC_CommandOutput="%Temp%\TC_CmdOutput.txt"
SET TC_PathToScriptFolder=%~dp0
SET TC_SqlCmdParameters=-S localhost -E -b

REM Process the input parameters
IF /I "%1"=="/?" (CALL :SubHelpPage & SET TC_ParametersExitCode=0& GOTO LblExit)
IF /I NOT "%1"=="" (
   ECHO Invalid command line parameters. The only valid parameter is /?.>&2
   GOTO :LblFatalError
)

REM Preparatory steps
CALL :SubSetupSupportDatabases   & IF ERRORLEVEL 1 (GOTO LblFatalError)

REM Running actual validations
CALL :SubRunUnitTestsOnTST & IF ERRORLEVEL 1 (GOTO LblFatalError)
CALL :SubValidateTSTBatch  & IF ERRORLEVEL 1 (GOTO LblFatalError)
:LblDone

CALL :SubDropSupportDatabases
IF ERRORLEVEL 1 (
   ECHO.
   ECHO All tests passed but dropping some test databases failed.>&2
   SET TC_ExitCode=1
)

ECHO.
ECHO ==================================================================
ECHO.
IF "%TC_ExitCode%" == "0" (ECHO TSTCheck Status: All Tests Passed) ELSE (ECHO TSTCheck Status: Failure>&2)

:LblExit
EXIT /B %TC_ExitCode%
ENDLOCAL
GOTO :EOF

:LblFatalError
SET TC_ExitCode=1
GOTO LblDone


REM ==============================================================
REM Sets up the support databases neded to self check TST.
REM Return code: 
REM   0 - OK
REM   1 - An error occured. An error message was already displayed.
REM ==============================================================
:SubSetupSupportDatabases
SET TC_SetupSupportDBExitCode=0

REM Make sure that the current version of TST database is set-up.
ECHO.
CALL "%TC_PathToScriptFolder%TST.bat" /Force
IF ERRORLEVEL 1 (
   ECHO Error setting up the TST database.>&2
   SET TC_SetupSupportDBExitCode=1
   GOTO LblSupportDBDone
)

ECHO.
ECHO ===================== Prepare Test Databases =====================
ECHO.

REM make sure that TST.bat /QuickStart works fine
CALL "%TC_PathToScriptFolder%TST.bat" /QuickStart > %TC_SqlOutput% 2>&1
IF ERRORLEVEL 1 (
   ECHO TST.BAT /QuickStart failed.>&2
   TYPE %TC_SqlOutput% >&2
   SET TC_SetupSupportDBExitCode=1
   GOTO LblSupportDBDone
)

ECHO TST.BAT /QuickStart completed successfuly.

CALL :SubCreateDatabase TSTCheckSimple             & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheck                   & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckTran               & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckTransactionErrors  & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckTable              & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckError              & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckNoTests            & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckSchema             & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckTableEmptyOrNot    & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckTestSession        & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckTestSession2       & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckTestSessionErr     & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckView_TSTResultsEx  & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)
CALL :SubCreateDatabase TSTCheckMaster             & IF ERRORLEVEL 1 (SET TC_SetupSupportDBExitCode=1& GOTO LblSupportDBDone)

:LblSupportDBDone
EXIT /B %TC_SetupSupportDBExitCode%
GOTO :EOF

REM ==============================================================
REM This subroutine run the SQL script used to create a given database
REM Return code:
REM   0 - OK
REM   1 - An error occured. An error message was already displayed.
REM ==============================================================
:SubCreateDatabase

SET TC_CreateDBName=%~1
SET TC_CreateDBExitCode=0

sqlcmd %TC_SqlCmdParameters% -i "%TC_PathToScriptFolder%Test\Set%TC_CreateDBName%.sql" > %TC_SqlOutput% 2>&1
IF ERRORLEVEL 1 (
   ECHO Error setting up the %TC_CreateDBName% database.>&2
   TYPE %TC_SqlOutput% >&2
   SET TC_CreateDBExitCode=1
   GOTO LblCreateDBDone
)
ECHO Database %TC_CreateDBName% was successfuly set-up.

:LblCreateDBDone
EXIT /B %TC_CreateDBExitCode%
GOTO :EOF

REM ==============================================================
REM This subroutine will drop all the support databases that were created
REM Return code:
REM   0 - OK
REM   1 - An error occured. An error message was already displayed.
REM ==============================================================
:SubDropSupportDatabases

SET TC_DropSupportDBExitCode=0

ECHO.
ECHO ===================== Drop Test Databases ========================
ECHO.

CALL :SubDropDatabase TSTCheckSimple               & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheck                     & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTran                 & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTransactionErrors    & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTable                & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckError                & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckNoTests              & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckSchema               & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTableEmptyOrNot      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSession          & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSession2         & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSessionErr0      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSessionErr1      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSessionErr2      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSessionErr3      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSessionErr4      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSessionErr5      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSessionErr6      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSessionErr7      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckTestSessionErr8      & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckView_TSTResultsEx    & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTCheckMaster               & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)
CALL :SubDropDatabase TSTQuickStart                & IF ERRORLEVEL 1 (SET TC_DropSupportDBExitCode=1)

EXIT /B %TC_DropSupportDBExitCode%
GOTO :EOF

REM ==============================================================
REM This subroutine will drop a given database.
REM Return code:
REM   0 - OK
REM   1 - An error occured. An error message was already displayed.
REM ==============================================================
:SubDropDatabase

SET TC_DropDatabaseName=%~1
SET TC_DropDBExitCode=0

sqlcmd %TC_SqlCmdParameters% -Q "EXIT (SELECT COUNT([name]) FROM sys.databases WHERE [name] = '%TC_DropDatabaseName%')" > %TC_SqlOutput% 2>&1
IF "%ERRORLEVEL%"=="0" GOTO LblDropDBDone

sqlcmd %TC_SqlCmdParameters% -Q "DROP DATABASE [%TC_DropDatabaseName%]" > %TC_SqlOutput% 2>&1
IF ERRORLEVEL 1 (
   ECHO WARNING: Error dropping the database %TC_DropDatabaseName%.>&2
   TYPE %TC_SqlOutput% >&2
   SET TC_DropDBExitCode=1
   GOTO LblDropDBDone
) 
ECHO Database %TC_DropDatabaseName% dropped.

:LblDropDBDone
EXIT /B %TC_DropDBExitCode%
GOTO :EOF


REM ==============================================================
REM This subroutine executes the TST tests contained in 
REM the TSTCheckMaster database. This will self test the featurs 
REM in the TST database.
REM Return code: 
REM   0 - OK
REM   1 - An error or test failure occured. 
REM       An error message was already displayed.
REM ==============================================================
:SubRunUnitTestsOnTST

SET TC_UnitTestsExitCode=0
ECHO.
ECHO ===================== Execute the TST tests in TSTCheckMaster ====
ECHO.

CALL "%TC_PathToScriptFolder%TST.bat" /RunAll TSTCheckMaster
IF ERRORLEVEL 1 (
   SET TC_UnitTestsExitCode=1
   GOTO LblUnitTestsDone
)

:LblUnitTestsDone
EXIT /B %TC_UnitTestsExitCode%
GOTO :EOF

REM ==============================================================
REM This subroutine invokes TST.bat and compares its output 
REM against a baseline.
REM Return code: 
REM   0 - OK
REM   1 - An error or test failure occured. 
REM       An error message was already displayed.
REM ==============================================================
:SubValidateTSTBatch

SET TC_BatchTestsExitCode=0

ECHO.
ECHO ===================== Validate TST.BAT script output =============
ECHO.

CALL "%TC_PathToScriptFolder%TST.bat" /Help >%TC_CommandOutput% 2>&1
CALL :SubValidateAgainstBaseline "Help Page" %TC_CommandOutput% "%TC_PathToScriptFolder%Test\Baseline\HelpPage.txt"
IF ERRORLEVEL 1 (SET TC_BatchTestsExitCode=1&GOTO LblBatchTestsDone)

CALL "%TC_PathToScriptFolder%TST.bat" /RunAll TSTQuickStart /NoTimestamp >%TC_CommandOutput% 2>&1
CALL :SubValidateAgainstBaseline "Running tests in TSTQuickStart" %TC_CommandOutput% "%TC_PathToScriptFolder%Test\Baseline\QuickStart.txt"
IF ERRORLEVEL 1 (SET TC_BatchTestsExitCode=1&GOTO LblBatchTestsDone)

CALL "%TC_PathToScriptFolder%TST.bat" /RunAll TSTCheckSimple /NoTimestamp >%TC_CommandOutput% 2>&1
CALL :SubValidateAgainstBaseline "Simple Test Scenario" %TC_CommandOutput% "%TC_PathToScriptFolder%Test\Baseline\SimpleDb.txt"
IF ERRORLEVEL 1 (SET TC_BatchTestsExitCode=1&GOTO LblBatchTestsDone)

CALL "%TC_PathToScriptFolder%TST.bat" /RunAll TSTCheckSimple /NoTimestamp /Verbose >%TC_CommandOutput% 2>&1
CALL :SubValidateAgainstBaseline "Simple Test Scenario Verbose" %TC_CommandOutput% "%TC_PathToScriptFolder%Test\Baseline\SimpleDbVerbose.txt"
IF ERRORLEVEL 1 (SET TC_BatchTestsExitCode=1&GOTO LblBatchTestsDone)

CALL "%TC_PathToScriptFolder%TST.bat" /RunAll TSTCheckSimple /NoTimestamp /Verbose /XmlFormat %TC_CommandOutput% >nul 2>&1
CALL :SubValidateAgainstBaseline "Simple Test Scenario Xml Verbose" %TC_CommandOutput% "%TC_PathToScriptFolder%Test\Baseline\SimpleDbVerbose.xml"
IF ERRORLEVEL 1 (SET TC_BatchTestsExitCode=1&GOTO LblBatchTestsDone)

CALL "%TC_PathToScriptFolder%TEST\TSTErrorHandling.bat" %TC_CommandOutput%
CALL :SubValidateAgainstBaseline "Error Handling Scenarios" %TC_CommandOutput% "%TC_PathToScriptFolder%Test\Baseline\ErrorHandling.txt"
IF ERRORLEVEL 1 (SET TC_BatchTestsExitCode=1&GOTO LblBatchTestsDone)

:LblBatchTestsDone
EXIT /B %TC_BatchTestsExitCode%
GOTO :EOF

REM ==============================================================
REM Runs a command and compares the output with a baseline file
REM ==============================================================
:SubValidateAgainstBaseline

SET TC_TestCase=%1
SET TC_ActualOutput="%~2"
SET TC_BaselineOutput="%~3"

SET TC_ValidateBaselineExitCode=0

ECHO N | COMP %TC_ActualOutput% %TC_BaselineOutput% >nul 2>&1
IF ERRORLEVEL 1 (
   ECHO.
   ECHO Error comparing the ouput for %TC_TestCase% >&2
   ECHO      Output: %TC_CommandOutput% >&2
   ECHO    Baseline: %TC_BaselineOutput% >&2
   SET TC_ValidateBaselineExitCode=1
   GOTO LblValidateAgainstBaselineDone
)

ECHO Comparing the ouput for %TC_TestCase% OK

:LblValidateAgainstBaselineDone

EXIT /B %TC_ValidateBaselineExitCode%
GOTO :EOF


REM ==============================================================
REM Prints a help page to the output
REM ==============================================================
:SubHelpPage

ECHO.
ECHO TSTCheck.bat - Contains a self test for TST.
ECHO Usage: TSTCheck.bat [/?]
ECHO.       /?           Will display this help page.
ECHO.
ECHO TSTCheck.bat will run test automation that validates the TST framework.
ECHO.

GOTO :EOF
